function assimilate(obj,varargin)
%ASSIMILATE Assimilate new data to an SG object. 
%   ASSIMILATE(SGOBJ, StructObj) assimilate the canonical structure object
%   StructObj with the StratiGraph communication object.
%
%   ASSIMILATE(SGOBJ, A),
%   ASSIMILATE(SGOBJ, G, H),
%   ASSIMILATE(SGOBJ, A, B) assimilate the matrix A, matrix pencil G-sH, or
%   the controllability pair (A,B), respectively, with the StratiGraph
%   communication object.
%
%   See also SGCOM/IMPOSE.

narginchk(2,3);
nargoutchk(0,1);
  
if (isa(varargin{1},'mstruct') || ...
	isa(varargin{1},'pstruct') || ...
	isa(varargin{1},'ssstruct'))
	obj.mlstruct   = varargin{1};
	obj.A          = [];
	obj.B          = [];
else 
	switch obj.type
	case obj.MATRIX
		narginchk(2,2);
		obj.A          = varargin{1};
		obj.B          = [];
	case obj.PENCIL
		narginchk(3,3);
		obj.A          = varargin{1};
		obj.B          = varargin{2};
	case obj.PAIR
		narginchk(3,3);
		obj.A          = varargin{1};
		obj.B          = varargin{2};
	end 
end