function sgclose(label)
%SGCLOSE Close a StratiGraph window.
%   SGCLOSE(Label) close the StratiGraph window with label Label.
%   The label can either be a positive integer or a string.
%
%   SGCLOSE('all') close all opened StratiGraph windows. Even those
%   who are not opened from Matlab.
%
%   See also SGOPEN.

narginchk(1,1);

global MCS_PREF

% Close all
if strcmpi(label,'all')
  se.umu.stratigraph.core.util.Application.getApplication().closeAll();
  MCS_PREF.sgwin = struct([]);	
  return
end

if isnumeric(label)
  if isscalar(label)
    label = sprintf('%i',label);
  else
    error('MCS:sgclose', ['The ''label'' argument must be a character, ', ...
           'string, or a positive integer.']);
  end
elseif ~ischar(label)
  error('MCS:sgclose', ['The ''label'' argument must be a character, ', ...
         'string, or a positive integer.']);
end

openedLabels = sglabels();
if ~strcmpi(label,openedLabels)
  error('MCS:sgclose', ['No StratiGraph window with label ''%s'' activated ', ...
         'from Matlab exists.'],label)	
else
  sgapp = se.umu.stratigraph.core.util.Application.getApplication();
  appFrame = sgapp.getWindow(label);
  if ~isempty(appFrame)
    % Close window if open
    sgapp.closeWindow(appFrame.getId());
  end
  
  % Remove from MCS_PREF	
  tf = ~strcmpi(label,{MCS_PREF.sgwin.label});
  MCS_PREF.sgwin = MCS_PREF.sgwin(tf);
end